gchecky.model.carrier_calculated_shipping_t

Package gchecky :: Module model :: Class carrier_calculated_shipping_t |
[hide private]
[frames] | no frames]

# Class carrier_calculated_shipping_t

source code

    object --+
             |
     gxml.Node --+
                 |
                carrier_calculated_shipping_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| carrier_calculated_shipping_options = `List:PATH(carrier-calcul`...``
| shipping_packages = `List:PATH(shipping-packages):RE`...``
| _fields = ``{``'``carrier_calculated_shipping_options``'``:` List:PATH(ca`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### carrier_calculated_shipping_options Value:
      List:PATH(carrier-calculated-shipping-options):REQ:[
          Node:PATH(carrier-calculated-shipping-option):REQ:{ carrier_calcul
      ated_shipping_option_t }
      ]

  ### shipping_packages Value:
      List:PATH(shipping-packages):REQ:[
          Node:PATH(shipping-package):REQ:{ shipping_package_t }
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'carrier_calculated_shipping_options': List:PATH(carrier-calculated-s
      hipping-options):REQ:[
          Node:PATH(carrier-calculated-shipping-option):REQ:{ carrier_calcul
      ated_shipping_option_t }
      ],
       'shipping_packages': List:PATH(shipping-packages):REQ:[
          Node:PATH(shipping-package):REQ:{ shipping_package_t }
      ]}